@@ -6,8 +6,8 @@
 ;; Keywords: convenience completion company forge
 ;; Homepage: https://github.com/pkryger/company-forge.el
 ;; Package-Requires: ((emacs "29.1") (company "1.0.0") (forge "0.5.0") (ghub "4.3.0"))
-;; Package-Version: 20251101.1346
-;; Package-Revision: 17f20cf41bd8
+;; Package-Version: 20251217.942
+;; Package-Revision: 690410aff610
 ;; SPDX-License-Identifier: MIT
 
 ;;; Commentary:
@@ -448,7 +448,7 @@ when documentation is presented in a quickhelp popup of
                                      (zero-or-one identifier))))
                            (or "," whitespace line-end string-end)))))
                   ((string-match (
-                                  rx "/" alphanumeric (group (zero-or-more any)))
+                                  rx "/" alphanumeric (group (zero-or-more not-newline)))
                                  prefix)
                    (when-let* ((length (- 37
                                           (length (match-string-no-properties 1))))
@@ -464,7 +464,7 @@ when documentation is presented in a quickhelp popup of
                                      (or alphanumeric "-")))
                             (or "," whitespace line-end string-end))))
                   ((string-match
-                    (rx "@" alphanumeric (group (zero-or-more any)))
+                    (rx "@" alphanumeric (group (zero-or-more not-newline)))
                     prefix)
                    (when-let* ((length (- 37
                                           (length (match-string-no-properties 1))))
